package com.google.developers.schemas.impl;

import java.lang.Boolean;
import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.Number;
import org.schema.PriceSpecification;
import org.schema.QuantitativeValue;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A structured value representing a monetary amount. Typically, only the subclasses of this type are used for markup.
 */
public class PriceSpecificationImpl extends SchemaObjectImpl implements PriceSpecification {


  private ThingImpl thing;

  /**
   * The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.
   */
  private List<QuantitativeValue> eligibleQuantity = new LinkedList<QuantitativeValue>();
  
  /**
   * The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.
   */
  private List<PriceSpecification> eligibleTransactionVolume = new LinkedList<PriceSpecification>();
  
  /**
   * The highest price if the price is a range.
   */
  private List<Number> maxPrice = new LinkedList<Number>();
  
  /**
   * The lowest price if the price is a range.
   */
  private List<Number> minPrice = new LinkedList<Number>();
  
  /**
   * The offer price of a product, or of a price component when attached to PriceSpecification and its subtypes.
   */
  private List<Thing> price = new LinkedList<Thing>();
  
  /**
   * The currency (in 3-letter ISO 4217 format) of the price or a price component, when attached to PriceSpecification and its subtypes.
   */
  private List<String> priceCurrency = new LinkedList<String>();
  
  /**
   * The date when the item becomes valid.
   */
  private List<Date> validFrom = new LinkedList<Date>();
  
  /**
   * The end of the validity of offer, price specification, or opening hours data.
   */
  private List<Date> validThrough = new LinkedList<Date>();
  
  /**
   * Specifies whether the applicable value-added tax (VAT) is included in the price specification or not.
   */
  private List<Boolean> valueAddedTaxIncluded = new LinkedList<Boolean>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public PriceSpecificationImpl() {
    super("http://schema.org/PriceSpecification");
  }
  /**
   * Get a single additionalType property value for this PriceSpecification object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this PriceSpecification object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this PriceSpecification object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single eligibleQuantity property value for this PriceSpecification object.
   *
   * @return The first eligibleQuantity property value.
   */
  public QuantitativeValue getEligibleQuantity() {
  	return this.eligibleQuantity.isEmpty() ? null : this.eligibleQuantity.get(0);
  }
  
  /**
   * Get a single eligibleTransactionVolume property value for this PriceSpecification object.
   *
   * @return The first eligibleTransactionVolume property value.
   */
  public PriceSpecification getEligibleTransactionVolume() {
  	return this.eligibleTransactionVolume.isEmpty() ? null : this.eligibleTransactionVolume.get(0);
  }
  
  /**
   * Get a single image property value for this PriceSpecification object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single maxPrice property value for this PriceSpecification object.
   *
   * @return The first maxPrice property value.
   */
  public Number getMaxPrice() {
  	return this.maxPrice.isEmpty() ? null : this.maxPrice.get(0);
  }
  
  /**
   * Get a single minPrice property value for this PriceSpecification object.
   *
   * @return The first minPrice property value.
   */
  public Number getMinPrice() {
  	return this.minPrice.isEmpty() ? null : this.minPrice.get(0);
  }
  
  /**
   * Get a single name property value for this PriceSpecification object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single price property value for this PriceSpecification object.
   *
   * @return The first price property value.
   */
  public Thing getPrice() {
  	return this.price.isEmpty() ? null : this.price.get(0);
  }
  
  /**
   * Get a single priceCurrency property value for this PriceSpecification object.
   *
   * @return The first priceCurrency property value.
   */
  public String getPriceCurrency() {
  	return this.priceCurrency.isEmpty() ? null : this.priceCurrency.get(0);
  }
  
  /**
   * Get a single sameAs property value for this PriceSpecification object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this PriceSpecification object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single validFrom property value for this PriceSpecification object.
   *
   * @return The first validFrom property value.
   */
  public Date getValidFrom() {
  	return this.validFrom.isEmpty() ? null : this.validFrom.get(0);
  }
  
  /**
   * Get a single validThrough property value for this PriceSpecification object.
   *
   * @return The first validThrough property value.
   */
  public Date getValidThrough() {
  	return this.validThrough.isEmpty() ? null : this.validThrough.get(0);
  }
  
  /**
   * Get a single valueAddedTaxIncluded property value for this PriceSpecification object.
   *
   * @return The first valueAddedTaxIncluded property value.
   */
  public Boolean getValueAddedTaxIncluded() {
  	return this.valueAddedTaxIncluded.isEmpty() ? null : this.valueAddedTaxIncluded.get(0);
  }
  
  /**
   * Get all the additionalType property values for this PriceSpecification object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this PriceSpecification object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this PriceSpecification object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the eligibleQuantity property values for this PriceSpecification object.
   *
   * @return A list of eligibleQuantity property values.
   */
  public List<QuantitativeValue> getEligibleQuantities() {
  	return this.eligibleQuantity;
  }
  
  /**
   * Get all the eligibleTransactionVolume property values for this PriceSpecification object.
   *
   * @return A list of eligibleTransactionVolume property values.
   */
  public List<PriceSpecification> getEligibleTransactionVolumes() {
  	return this.eligibleTransactionVolume;
  }
  
  /**
   * Get all the image property values for this PriceSpecification object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the maxPrice property values for this PriceSpecification object.
   *
   * @return A list of maxPrice property values.
   */
  public List<Number> getMaxPrices() {
  	return this.maxPrice;
  }
  
  /**
   * Get all the minPrice property values for this PriceSpecification object.
   *
   * @return A list of minPrice property values.
   */
  public List<Number> getMinPrices() {
  	return this.minPrice;
  }
  
  /**
   * Get all the name property values for this PriceSpecification object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the price property values for this PriceSpecification object.
   *
   * @return A list of price property values.
   */
  public List<Thing> getPrices() {
  	return this.price;
  }
  
  /**
   * Get all the priceCurrency property values for this PriceSpecification object.
   *
   * @return A list of priceCurrency property values.
   */
  public List<String> getPriceCurrencies() {
  	return this.priceCurrency;
  }
  
  /**
   * Get all the sameAs property values for this PriceSpecification object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this PriceSpecification object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the validFrom property values for this PriceSpecification object.
   *
   * @return A list of validFrom property values.
   */
  public List<Date> getValidFroms() {
  	return this.validFrom;
  }
  
  /**
   * Get all the validThrough property values for this PriceSpecification object.
   *
   * @return A list of validThrough property values.
   */
  public List<Date> getValidThroughs() {
  	return this.validThrough;
  }
  
  /**
   * Get all the valueAddedTaxIncluded property values for this PriceSpecification object.
   *
   * @return A list of valueAddedTaxIncluded property values.
   */
  public List<Boolean> getValueAddedTaxIncludeds() {
  	return this.valueAddedTaxIncluded;
  }
  
  /**
   * Set the additionalType property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the eligibleQuantity property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param eligibleQuantity The value to set.
   */
  public void setEligibleQuantity(QuantitativeValue eligibleQuantity) {
  	this.eligibleQuantity.clear();
  	this.eligibleQuantity.add(eligibleQuantity);
  }
  
  /**
   * Set the eligibleTransactionVolume property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param eligibleTransactionVolume The value to set.
   */
  public void setEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume) {
  	this.eligibleTransactionVolume.clear();
  	this.eligibleTransactionVolume.add(eligibleTransactionVolume);
  }
  
  /**
   * Set the image property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the maxPrice property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param maxPrice The value to set.
   */
  public void setMaxPrice(Number maxPrice) {
  	this.maxPrice.clear();
  	this.maxPrice.add(maxPrice);
  }
  
  /**
   * Set the minPrice property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param minPrice The value to set.
   */
  public void setMinPrice(Number minPrice) {
  	this.minPrice.clear();
  	this.minPrice.add(minPrice);
  }
  
  /**
   * Set the name property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the price property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param price The value to set.
   */
  public void setPrice(Thing price) {
  	this.price.clear();
  	this.price.add(price);
  }
  
  /**
   * Set the priceCurrency property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param priceCurrency The value to set.
   */
  public void setPriceCurrency(String priceCurrency) {
  	this.priceCurrency.clear();
  	this.priceCurrency.add(priceCurrency);
  }
  
  /**
   * Set the sameAs property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the validFrom property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param validFrom The value to set.
   */
  public void setValidFrom(Date validFrom) {
  	this.validFrom.clear();
  	this.validFrom.add(validFrom);
  }
  
  /**
   * Set the validThrough property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param validThrough The value to set.
   */
  public void setValidThrough(Date validThrough) {
  	this.validThrough.clear();
  	this.validThrough.add(validThrough);
  }
  
  /**
   * Set the valueAddedTaxIncluded property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param valueAddedTaxIncluded The value to set.
   */
  public void setValueAddedTaxIncluded(Boolean valueAddedTaxIncluded) {
  	this.valueAddedTaxIncluded.clear();
  	this.valueAddedTaxIncluded.add(valueAddedTaxIncluded);
  }
  
  /**
   * Set the additionalType property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the eligibleQuantity property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param eligibleQuantities The list of values to set.
   */
  public void setEligibleQuantities(List<QuantitativeValue> eligibleQuantities) {
  	this.eligibleQuantity = eligibleQuantities;
  }
  
  /**
   * Set the eligibleTransactionVolume property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param eligibleTransactionVolumes The list of values to set.
   */
  public void setEligibleTransactionVolumes(List<PriceSpecification> eligibleTransactionVolumes) {
  	this.eligibleTransactionVolume = eligibleTransactionVolumes;
  }
  
  /**
   * Set the image property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the maxPrice property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param maxPrices The list of values to set.
   */
  public void setMaxPrices(List<Number> maxPrices) {
  	this.maxPrice = maxPrices;
  }
  
  /**
   * Set the minPrice property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param minPrices The list of values to set.
   */
  public void setMinPrices(List<Number> minPrices) {
  	this.minPrice = minPrices;
  }
  
  /**
   * Set the name property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the price property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param prices The list of values to set.
   */
  public void setPrices(List<Thing> prices) {
  	this.price = prices;
  }
  
  /**
   * Set the priceCurrency property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param priceCurrencies The list of values to set.
   */
  public void setPriceCurrencies(List<String> priceCurrencies) {
  	this.priceCurrency = priceCurrencies;
  }
  
  /**
   * Set the sameAs property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the validFrom property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param validFroms The list of values to set.
   */
  public void setValidFroms(List<Date> validFroms) {
  	this.validFrom = validFroms;
  }
  
  /**
   * Set the validThrough property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param validThroughs The list of values to set.
   */
  public void setValidThroughs(List<Date> validThroughs) {
  	this.validThrough = validThroughs;
  }
  
  /**
   * Set the valueAddedTaxIncluded property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param valueAddedTaxIncludeds The list of values to set.
   */
  public void setValueAddedTaxIncludeds(List<Boolean> valueAddedTaxIncludeds) {
  	this.valueAddedTaxIncluded = valueAddedTaxIncludeds;
  }
  
  /**
   * Adds a additionalType property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a eligibleQuantity property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param eligibleQuantity The value to add.
   */
  public void addEligibleQuantity(QuantitativeValue eligibleQuantity) {
  	this.eligibleQuantity.add(eligibleQuantity);
  }
  
  /**
   * Adds a eligibleTransactionVolume property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param eligibleTransactionVolume The value to add.
   */
  public void addEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume) {
  	this.eligibleTransactionVolume.add(eligibleTransactionVolume);
  }
  
  /**
   * Adds a image property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a maxPrice property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param maxPrice The value to add.
   */
  public void addMaxPrice(Number maxPrice) {
  	this.maxPrice.add(maxPrice);
  }
  
  /**
   * Adds a minPrice property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param minPrice The value to add.
   */
  public void addMinPrice(Number minPrice) {
  	this.minPrice.add(minPrice);
  }
  
  /**
   * Adds a name property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a price property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param price The value to add.
   */
  public void addPrice(Thing price) {
  	this.price.add(price);
  }
  
  /**
   * Adds a priceCurrency property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param priceCurrency The value to add.
   */
  public void addPriceCurrency(String priceCurrency) {
  	this.priceCurrency.add(priceCurrency);
  }
  
  /**
   * Adds a sameAs property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a validFrom property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param validFrom The value to add.
   */
  public void addValidFrom(Date validFrom) {
  	this.validFrom.add(validFrom);
  }
  
  /**
   * Adds a validThrough property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param validThrough The value to add.
   */
  public void addValidThrough(Date validThrough) {
  	this.validThrough.add(validThrough);
  }
  
  /**
   * Adds a valueAddedTaxIncluded property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param valueAddedTaxIncluded The value to add.
   */
  public void addValueAddedTaxIncluded(Boolean valueAddedTaxIncluded) {
  	this.valueAddedTaxIncluded.add(valueAddedTaxIncluded);
  }
  
}