package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.MedicalCode;
import org.schema.MedicalCondition;
import org.schema.MedicalGuideline;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicalTherapy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.SuperficialAnatomy;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * Anatomical features that can be observed by sight (without dissection), including the form and proportions of the human body as well as surface landmarks that correspond to deeper subcutaneous structures. Superficial anatomy plays an important role in sports medicine, phlebotomy, and other medical specialties as underlying anatomical structures can be identified through surface palpation. For example, during back surgery, superficial anatomy can be used to palpate and count vertebrae to find the site of incision. Or in phlebotomy, superficial anatomy can be used to locate an underlying vein; for example, the median cubital vein can be located by palpating the borders of the cubital fossa (such as the epicondyles of the humerus) and then looking for the superficial signs of the vein, such as size, prominence, ability to refill after depression, and feel of surrounding tissue support. As another example, in a subluxation (dislocation) of the glenohumeral joint, the bony structure becomes pronounced with the deltoid muscle failing to cover the glenohumeral joint allowing the edges of the scapula to be superficially visible. Here, the superficial anatomy is the visible edges of the scapula, implying the underlying dislocation of the joint (the related anatomical structure).
 */
public class SuperficialAnatomyImpl extends SchemaObjectImpl implements SuperficialAnatomy {


  private MedicalEntityImpl medicalEntity;
  private ThingImpl thing;

  /**
   * If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.
   */
  private List<String> associatedPathophysiology = new LinkedList<String>();
  
  /**
   * Anatomical systems or structures that relate to the superficial anatomy.
   */
  private List<Thing> relatedAnatomy = new LinkedList<Thing>();
  
  /**
   * A medical condition associated with this anatomy.
   */
  private List<MedicalCondition> relatedCondition = new LinkedList<MedicalCondition>();
  
  /**
   * A medical therapy related to this anatomy.
   */
  private List<MedicalTherapy> relatedTherapy = new LinkedList<MedicalTherapy>();
  
  /**
   * The significance associated with the superficial anatomy; as an example, how characteristics of the superficial anatomy can suggest underlying medical conditions or courses of treatment.
   */
  private List<String> significance = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public SuperficialAnatomyImpl() {
    super("http://schema.org/SuperficialAnatomy");
    medicalEntity = new MedicalEntityImpl();
  }
  /**
   * Get a single additionalType property value for this SuperficialAnatomy object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this SuperficialAnatomy object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single associatedPathophysiology property value for this SuperficialAnatomy object.
   *
   * @return The first associatedPathophysiology property value.
   */
  public String getAssociatedPathophysiology() {
  	return this.associatedPathophysiology.isEmpty() ? null : this.associatedPathophysiology.get(0);
  }
  
  /**
   * Get a single code property value for this SuperficialAnatomy object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single description property value for this SuperficialAnatomy object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single guideline property value for this SuperficialAnatomy object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this SuperficialAnatomy object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single medicineSystem property value for this SuperficialAnatomy object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this SuperficialAnatomy object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single recognizingAuthority property value for this SuperficialAnatomy object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relatedAnatomy property value for this SuperficialAnatomy object.
   *
   * @return The first relatedAnatomy property value.
   */
  public Thing getRelatedAnatomy() {
  	return this.relatedAnatomy.isEmpty() ? null : this.relatedAnatomy.get(0);
  }
  
  /**
   * Get a single relatedCondition property value for this SuperficialAnatomy object.
   *
   * @return The first relatedCondition property value.
   */
  public MedicalCondition getRelatedCondition() {
  	return this.relatedCondition.isEmpty() ? null : this.relatedCondition.get(0);
  }
  
  /**
   * Get a single relatedTherapy property value for this SuperficialAnatomy object.
   *
   * @return The first relatedTherapy property value.
   */
  public MedicalTherapy getRelatedTherapy() {
  	return this.relatedTherapy.isEmpty() ? null : this.relatedTherapy.get(0);
  }
  
  /**
   * Get a single relevantSpecialty property value for this SuperficialAnatomy object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this SuperficialAnatomy object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single significance property value for this SuperficialAnatomy object.
   *
   * @return The first significance property value.
   */
  public String getSignificance() {
  	return this.significance.isEmpty() ? null : this.significance.get(0);
  }
  
  /**
   * Get a single study property value for this SuperficialAnatomy object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single url property value for this SuperficialAnatomy object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this SuperficialAnatomy object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this SuperficialAnatomy object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the associatedPathophysiology property values for this SuperficialAnatomy object.
   *
   * @return A list of associatedPathophysiology property values.
   */
  public List<String> getAssociatedPathophysiologies() {
  	return this.associatedPathophysiology;
  }
  
  /**
   * Get all the code property values for this SuperficialAnatomy object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the description property values for this SuperficialAnatomy object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the guideline property values for this SuperficialAnatomy object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this SuperficialAnatomy object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the medicineSystem property values for this SuperficialAnatomy object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this SuperficialAnatomy object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the recognizingAuthority property values for this SuperficialAnatomy object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relatedAnatomy property values for this SuperficialAnatomy object.
   *
   * @return A list of relatedAnatomy property values.
   */
  public List<Thing> getRelatedAnatomies() {
  	return this.relatedAnatomy;
  }
  
  /**
   * Get all the relatedCondition property values for this SuperficialAnatomy object.
   *
   * @return A list of relatedCondition property values.
   */
  public List<MedicalCondition> getRelatedConditions() {
  	return this.relatedCondition;
  }
  
  /**
   * Get all the relatedTherapy property values for this SuperficialAnatomy object.
   *
   * @return A list of relatedTherapy property values.
   */
  public List<MedicalTherapy> getRelatedTherapies() {
  	return this.relatedTherapy;
  }
  
  /**
   * Get all the relevantSpecialty property values for this SuperficialAnatomy object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this SuperficialAnatomy object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the significance property values for this SuperficialAnatomy object.
   *
   * @return A list of significance property values.
   */
  public List<String> getSignificances() {
  	return this.significance;
  }
  
  /**
   * Get all the study property values for this SuperficialAnatomy object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the url property values for this SuperficialAnatomy object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the associatedPathophysiology property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param associatedPathophysiology The value to set.
   */
  public void setAssociatedPathophysiology(String associatedPathophysiology) {
  	this.associatedPathophysiology.clear();
  	this.associatedPathophysiology.add(associatedPathophysiology);
  }
  
  /**
   * Set the code property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the description property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the guideline property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the medicineSystem property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the recognizingAuthority property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relatedAnatomy property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedAnatomy The value to set.
   */
  public void setRelatedAnatomy(Thing relatedAnatomy) {
  	this.relatedAnatomy.clear();
  	this.relatedAnatomy.add(relatedAnatomy);
  }
  
  /**
   * Set the relatedCondition property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedCondition The value to set.
   */
  public void setRelatedCondition(MedicalCondition relatedCondition) {
  	this.relatedCondition.clear();
  	this.relatedCondition.add(relatedCondition);
  }
  
  /**
   * Set the relatedTherapy property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedTherapy The value to set.
   */
  public void setRelatedTherapy(MedicalTherapy relatedTherapy) {
  	this.relatedTherapy.clear();
  	this.relatedTherapy.add(relatedTherapy);
  }
  
  /**
   * Set the relevantSpecialty property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the significance property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param significance The value to set.
   */
  public void setSignificance(String significance) {
  	this.significance.clear();
  	this.significance.add(significance);
  }
  
  /**
   * Set the study property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the url property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the associatedPathophysiology property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param associatedPathophysiologies The list of values to set.
   */
  public void setAssociatedPathophysiologies(List<String> associatedPathophysiologies) {
  	this.associatedPathophysiology = associatedPathophysiologies;
  }
  
  /**
   * Set the code property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the description property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the guideline property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the medicineSystem property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the recognizingAuthority property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relatedAnatomy property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedAnatomies The list of values to set.
   */
  public void setRelatedAnatomies(List<Thing> relatedAnatomies) {
  	this.relatedAnatomy = relatedAnatomies;
  }
  
  /**
   * Set the relatedCondition property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedConditions The list of values to set.
   */
  public void setRelatedConditions(List<MedicalCondition> relatedConditions) {
  	this.relatedCondition = relatedConditions;
  }
  
  /**
   * Set the relatedTherapy property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedTherapies The list of values to set.
   */
  public void setRelatedTherapies(List<MedicalTherapy> relatedTherapies) {
  	this.relatedTherapy = relatedTherapies;
  }
  
  /**
   * Set the relevantSpecialty property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the significance property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param significances The list of values to set.
   */
  public void setSignificances(List<String> significances) {
  	this.significance = significances;
  }
  
  /**
   * Set the study property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the url property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a associatedPathophysiology property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param associatedPathophysiology The value to add.
   */
  public void addAssociatedPathophysiology(String associatedPathophysiology) {
  	this.associatedPathophysiology.add(associatedPathophysiology);
  }
  
  /**
   * Adds a code property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a description property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a guideline property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a medicineSystem property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a recognizingAuthority property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relatedAnatomy property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param relatedAnatomy The value to add.
   */
  public void addRelatedAnatomy(Thing relatedAnatomy) {
  	this.relatedAnatomy.add(relatedAnatomy);
  }
  
  /**
   * Adds a relatedCondition property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param relatedCondition The value to add.
   */
  public void addRelatedCondition(MedicalCondition relatedCondition) {
  	this.relatedCondition.add(relatedCondition);
  }
  
  /**
   * Adds a relatedTherapy property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param relatedTherapy The value to add.
   */
  public void addRelatedTherapy(MedicalTherapy relatedTherapy) {
  	this.relatedTherapy.add(relatedTherapy);
  }
  
  /**
   * Adds a relevantSpecialty property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a significance property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param significance The value to add.
   */
  public void addSignificance(String significance) {
  	this.significance.add(significance);
  }
  
  /**
   * Adds a study property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a url property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}