package org.schema;

import java.util.Date;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.DataCatalog;
import org.schema.DataDownload;
import org.schema.Place;
import org.schema.SchemaObject;

/**
 * A body of structured information describing some topic(s) of interest.
 */
public interface Dataset extends CreativeWork, SchemaObject {

  /**
   * Get a single catalog property value for this Dataset object.
   *
   * @return The first catalog property value.
   */
  public DataCatalog getCatalog();
  
  /**
   * Get a single distribution property value for this Dataset object.
   *
   * @return The first distribution property value.
   */
  public DataDownload getDistribution();
  
  /**
   * Get a single spatial property value for this Dataset object.
   *
   * @return The first spatial property value.
   */
  public Place getSpatial();
  
  /**
   * Get a single temporal property value for this Dataset object.
   *
   * @return The first temporal property value.
   */
  public Date getTemporal();
  
  /**
   * Get all the catalog property values for this Dataset object.
   *
   * @return A list of catalog property values.
   */
  public List<DataCatalog> getCatalogs();
  
  /**
   * Get all the distribution property values for this Dataset object.
   *
   * @return A list of distribution property values.
   */
  public List<DataDownload> getDistributions();
  
  /**
   * Get all the spatial property values for this Dataset object.
   *
   * @return A list of spatial property values.
   */
  public List<Place> getSpatials();
  
  /**
   * Get all the temporal property values for this Dataset object.
   *
   * @return A list of temporal property values.
   */
  public List<Date> getTemporals();
  
  /**
   * Set the catalog property value for this Dataset object; overwriting any existing values.
   *
   * @param catalog The value to set.
   */
  public void setCatalog(DataCatalog catalog);
  
  /**
   * Set the distribution property value for this Dataset object; overwriting any existing values.
   *
   * @param distribution The value to set.
   */
  public void setDistribution(DataDownload distribution);
  
  /**
   * Set the spatial property value for this Dataset object; overwriting any existing values.
   *
   * @param spatial The value to set.
   */
  public void setSpatial(Place spatial);
  
  /**
   * Set the temporal property value for this Dataset object; overwriting any existing values.
   *
   * @param temporal The value to set.
   */
  public void setTemporal(Date temporal);
  
  /**
   * Set the catalog property values for this Dataset object; overwriting any existing values.
   *
   * @param catalogs The list of values to set.
   */
  public void setCatalogs(List<DataCatalog> catalogs);
  
  /**
   * Set the distribution property values for this Dataset object; overwriting any existing values.
   *
   * @param distributions The list of values to set.
   */
  public void setDistributions(List<DataDownload> distributions);
  
  /**
   * Set the spatial property values for this Dataset object; overwriting any existing values.
   *
   * @param spatials The list of values to set.
   */
  public void setSpatials(List<Place> spatials);
  
  /**
   * Set the temporal property values for this Dataset object; overwriting any existing values.
   *
   * @param temporals The list of values to set.
   */
  public void setTemporals(List<Date> temporals);
  
  /**
   * Adds a catalog property value for this Dataset object; appending it to the list of existing values.
   *
   * @param catalog The value to add.
   */
  public void addCatalog(DataCatalog catalog);
  
  /**
   * Adds a distribution property value for this Dataset object; appending it to the list of existing values.
   *
   * @param distribution The value to add.
   */
  public void addDistribution(DataDownload distribution);
  
  /**
   * Adds a spatial property value for this Dataset object; appending it to the list of existing values.
   *
   * @param spatial The value to add.
   */
  public void addSpatial(Place spatial);
  
  /**
   * Adds a temporal property value for this Dataset object; appending it to the list of existing values.
   *
   * @param temporal The value to add.
   */
  public void addTemporal(Date temporal);
  
}